===========
 Changelog
===========

1.2 (2016-08-28)
================

- Add a forecast list below the calendar. It contains the special events of
  the next year.


1.1 (2016-06-25)
================

- Fix error on export if no categories where selected in master data.

- Add ability to render a special CSS class for certain events.

- Add ability to render an event as a hyperlink.

- Use `py.test` fixtures in the tests + convert tests to use the class-less
  approach.

- Make compatible with `icemac.ab.calendar` 1.8 thus requiring at least this
  version.


1.0.0 (2015-05-24)
==================

- Initial release.
